@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -32,7 +32,7 @@ public:
     explicit BlackListBalooEmailSearchJob(QObject *parent = nullptr);
     ~BlackListBalooEmailSearchJob();
 
-    bool start();
+    Q_REQUIRED_RESULT bool start();
 
     void setSearchEmail(const QString &searchEmail);
 
